==> dev-console-widget-1.0.12.tgz: package/src/components/dev-console-products.ts <==
/**
 * @license
 * Copyright 2019 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */

 import {LitElement, html, CSSResultGroup} from 'lit';
 import {customElement} from 'lit/decorators.js';
 import { products } from '../staticData/products';
import { globalStyles } from '../styles';
 /**
  * @fires count-changed - Indicates when the count changes
  * @slot - This element has a slot
  * @csspart button - The button
  */
 @customElement('dev-console-products')
 export class DevConsoleProducts extends LitElement {
    static override styles?: CSSResultGroup | undefined = [globalStyles];
     override render(){
         return html`
            <div class="flex flex-col space-y-2">
                <strong class="pl-6">Browse Products</strong>
                <ul class="list-none flex-col">
                ${products.map((product) =>
                    html`
                        <li class="flex space-x-2 items-center text-sm font-semibold px-6 py-2 text-gray-600 cursor-pointer hover:bg-blue-500 hover:text-white" value=${product.uniqueKey} @click=${()=>this._dispatchSelect(product.uniqueKey)}> 
                        ${product.svg}    
                        <span>${product.name}</span>
                        </li>
                    `
                )}
                </ul>
            </div>
         `
     }

     private _dispatchSelect(uniqueKey:string) {
        if (uniqueKey) {
          const options = {
            detail: {uniqueKey},
            bubbles: true,
            composed: true
          };
          this.dispatchEvent(new CustomEvent('productSelect', options));
        }
      }
    
 }

 declare global {
    interface HTMLElementTagNameMap {
      'dev-console-products': DevConsoleProducts;
    }
  }

==> dev-console-widget-1.0.13.tgz: package/src/components/dev-console-products.ts <==
/**
 * @license
 * Copyright 2019 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */

 import {LitElement, html, CSSResultGroup} from 'lit';
 import {customElement} from 'lit/decorators.js';
 import { products } from '../staticData/products';
import { globalStyles } from '../styles';
 /**
  * @fires count-changed - Indicates when the count changes
  * @slot - This element has a slot
  * @csspart button - The button
  */
 @customElement('dev-console-products')
 export class DevConsoleProducts extends LitElement {
    static override styles?: CSSResultGroup | undefined = [globalStyles];
     override render(){
         return html`
            <div class="flex flex-col space-y-2">
                <strong class="pl-6">Browse Products</strong>
                <ul class="list-none flex-col">
                ${products.map((product) =>
                    html`
                        <li class="flex space-x-2 items-center text-sm font-semibold px-6 py-2 text-gray-600 cursor-pointer hover:bg-blue-500 hover:text-white" value=${product.uniqueKey} @click=${()=>this._dispatchSelect(product.uniqueKey)}> 
                        ${product.svg}    
                        <span class="text-xs font-semibold text-gray-700">${product.name}</span>
                        </li>
                    `
                )}
                </ul>
            </div>
         `
     }

     private _dispatchSelect(uniqueKey:string) {
        if (uniqueKey) {
          const options = {
            detail: {uniqueKey},
            bubbles: true,
            composed: true
          };
          this.dispatchEvent(new CustomEvent('productSelect', options));
        }
      }
    
 }

 declare global {
    interface HTMLElementTagNameMap {
      'dev-console-products': DevConsoleProducts;
    }
  }
